@@ -5,7 +5,7 @@ returned from the API to indicate errors.
 http://docs.veritranspay.co.id/sandbox/status_code.html
 '''
 # 20x - successful submission to api
-SUCCESS = 200
+SUCCESS = 200  # NOTE: this is returned when manually cancelled too!
 CHALLENGE = 201
 DENIED = 202
 
@@ -25,10 +25,9 @@ ACCOUNT_INACTIVE = 410
 TOKEN_ERROR = 411
 
 
-
 # 50x
 SERVER_ERROR = 500
 FEATURE_UNAVAILABLE = 501
 BANK_CONNECTION_PROBLEM = 502
 SERVER_ERROR_OTHER = 503
-FRAUD_DETECTION_UNAVAILABLE = 504
\ No newline at end of file
+FRAUD_DETECTION_UNAVAILABLE = 504
